-
number of tags are available, and here are some examples to get you started.'); ?>
+
URLs which have question marks and lots of numbers in them, however WordPress offers you the ability to create a custom URL structure for your permalinks and archives. This can improve the aesthetics, usability, and forward-compatibility of your links. A number of tags are available, and here are some examples to get you started.'); ?>
-
/taxonomy/tags would make your category links like http://example.org/taxonomy/tags/uncategorized/
. If you leave this blank the default will be used.') ?>
+
URLs here. For example, /taxonomy/tags
would make your category links like http://example.org/taxonomy/tags/uncategorized/
. If you leave this blank the default will be used.') ?>
-
/index.php/taxonomy/tags would make your category links like http://example.org/index.php/taxonomy/tags/uncategorized/
. If you leave this blank the default will be used.') ?>
+
URLs here. For example, /index.php/taxonomy/tags
would make your category links like http://example.org/index.php/taxonomy/tags/uncategorized/
. If you leave this blank the default will be used.') ?>
:
diff --git a/wp-admin/options-writing.php b/wp-admin/options-writing.php
index 9bc454ea48..988f3f9262 100644
--- a/wp-admin/options-writing.php
+++ b/wp-admin/options-writing.php
@@ -96,7 +96,7 @@ endforeach;
diff --git a/wp-content/themes/classic/comments-popup.php b/wp-content/themes/classic/comments-popup.php
index 49ffe3c020..677f4fd46f 100644
--- a/wp-content/themes/classic/comments-popup.php
+++ b/wp-content/themes/classic/comments-popup.php
@@ -24,7 +24,7 @@ foreach ($posts as $post) { start_wp();
RSS feed for comments on this post."); ?>
ping_status) { ?>
-
URI to TrackBack this entry is:"); ?>
+
URL to TrackBack this entry is:"); ?>
post_password) && $_COOKIE['wp-postpass_'. COOKIEHASH
-
+
diff --git a/wp-content/themes/classic/comments.php b/wp-content/themes/classic/comments.php
index 6222f1afa4..860e634731 100644
--- a/wp-content/themes/classic/comments.php
+++ b/wp-content/themes/classic/comments.php
@@ -27,7 +27,7 @@
RSS feed for comments on this post.')); ?>
- URI'); ?>
+ URL'); ?>
diff --git a/wp-content/themes/default/comments-popup.php b/wp-content/themes/default/comments-popup.php
index 3cd58a6628..43c45f9365 100644
--- a/wp-content/themes/default/comments-popup.php
+++ b/wp-content/themes/default/comments-popup.php
@@ -24,7 +24,7 @@ foreach ($posts as $post) { start_wp();
RSS feed for comments on this post.
ping_status) { ?>
-
The URI to TrackBack this entry is:
+
The URL to TrackBack this entry is:
post_password) && $_COOKIE['wp-postpass_'. COOKIEHASH] != $pos
-
+
diff --git a/wp-includes/comment.php b/wp-includes/comment.php
index f6422c1876..9a64225be3 100644
--- a/wp-includes/comment.php
+++ b/wp-includes/comment.php
@@ -553,7 +553,7 @@ function discover_pingback_server_uri($url, $timeout_bytes = 2048) {
$pingback_href_end = @strpos($contents, $quote, $pingback_href_start);
$pingback_server_url_len = $pingback_href_end - $pingback_href_start;
$pingback_server_url = substr($contents, $pingback_href_start, $pingback_server_url_len);
- // We may find rel="pingback" but an incomplete pingback URI
+ // We may find rel="pingback" but an incomplete pingback URL
if ($pingback_server_url_len > 0) {
// We got it!
return $pingback_server_url;
diff --git a/wp-includes/link-template.php b/wp-includes/link-template.php
index 55393aae93..37c6fbc61c 100644
--- a/wp-includes/link-template.php
+++ b/wp-includes/link-template.php
@@ -398,7 +398,7 @@ function get_pagenum_link($pagenum = 1) {
$qstr = preg_replace("#/*" . $index . "/*#", '/', $qstr);
} else {
// If using path info style permalinks, make sure the index is in
- // the URI.
+ // the URL.
if ( strpos($qstr, $index) === false )
$qstr = '/' . $index . $qstr;
}
diff --git a/wp-includes/pluggable.php b/wp-includes/pluggable.php
index 57eaecdd43..0d02fa8063 100644
--- a/wp-includes/pluggable.php
+++ b/wp-includes/pluggable.php
@@ -345,7 +345,7 @@ function wp_notify_postauthor($comment_id, $comment_type='') {
$notify_message = sprintf( __('New comment on your post #%1$s "%2$s"'), $comment->comment_post_ID, $post->post_title ) . "\r\n";
$notify_message .= sprintf( __('Author : %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
$notify_message .= sprintf( __('E-mail : %s'), $comment->comment_author_email ) . "\r\n";
- $notify_message .= sprintf( __('URI : %s'), $comment->comment_author_url ) . "\r\n";
+ $notify_message .= sprintf( __('URL : %s'), $comment->comment_author_url ) . "\r\n";
$notify_message .= sprintf( __('Whois : http://ws.arin.net/cgi-bin/whois.pl?queryinput=%s'), $comment->comment_author_IP ) . "\r\n";
$notify_message .= __('Comment: ') . "\r\n" . $comment->comment_content . "\r\n\r\n";
$notify_message .= __('You can see all comments on this post here: ') . "\r\n";
@@ -353,14 +353,14 @@ function wp_notify_postauthor($comment_id, $comment_type='') {
} elseif ('trackback' == $comment_type) {
$notify_message = sprintf( __('New trackback on your post #%1$s "%2$s"'), $comment->comment_post_ID, $post->post_title ) . "\r\n";
$notify_message .= sprintf( __('Website: %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
- $notify_message .= sprintf( __('URI : %s'), $comment->comment_author_url ) . "\r\n";
+ $notify_message .= sprintf( __('URL : %s'), $comment->comment_author_url ) . "\r\n";
$notify_message .= __('Excerpt: ') . "\r\n" . $comment->comment_content . "\r\n\r\n";
$notify_message .= __('You can see all trackbacks on this post here: ') . "\r\n";
$subject = sprintf( __('[%1$s] Trackback: "%2$s"'), $blogname, $post->post_title );
} elseif ('pingback' == $comment_type) {
$notify_message = sprintf( __('New pingback on your post #%1$s "%2$s"'), $comment->comment_post_ID, $post->post_title ) . "\r\n";
$notify_message .= sprintf( __('Website: %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
- $notify_message .= sprintf( __('URI : %s'), $comment->comment_author_url ) . "\r\n";
+ $notify_message .= sprintf( __('URL : %s'), $comment->comment_author_url ) . "\r\n";
$notify_message .= __('Excerpt: ') . "\r\n" . sprintf('[...] %s [...]', $comment->comment_content ) . "\r\n\r\n";
$notify_message .= __('You can see all pingbacks on this post here: ') . "\r\n";
$subject = sprintf( __('[%1$s] Pingback: "%2$s"'), $blogname, $post->post_title );
@@ -420,7 +420,7 @@ function wp_notify_moderator($comment_id) {
$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
$notify_message .= sprintf( __('Author : %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
$notify_message .= sprintf( __('E-mail : %s'), $comment->comment_author_email ) . "\r\n";
- $notify_message .= sprintf( __('URI : %s'), $comment->comment_author_url ) . "\r\n";
+ $notify_message .= sprintf( __('URL : %s'), $comment->comment_author_url ) . "\r\n";
$notify_message .= sprintf( __('Whois : http://ws.arin.net/cgi-bin/whois.pl?queryinput=%s'), $comment->comment_author_IP ) . "\r\n";
$notify_message .= __('Comment: ') . "\r\n" . $comment->comment_content . "\r\n\r\n";
$notify_message .= sprintf( __('To approve this comment, visit: %s'), get_settings('siteurl').'/wp-admin/comment.php?action=mailapprovecomment&p='.$comment->comment_post_ID."&comment=$comment_id" ) . "\r\n";
diff --git a/wp-includes/post.php b/wp-includes/post.php
index 7aa9ffe63c..7d5b47840c 100644
--- a/wp-includes/post.php
+++ b/wp-includes/post.php
@@ -814,7 +814,7 @@ function wp_set_post_categories($post_ID = 0, $post_categories = array()) {
// Trackback and ping functions
//
-function add_ping($post_id, $uri) { // Add a URI to those already pung
+function add_ping($post_id, $uri) { // Add a URL to those already pung
global $wpdb;
$pung = $wpdb->get_var("SELECT pinged FROM $wpdb->posts WHERE ID = $post_id");
$pung = trim($pung);
@@ -844,7 +844,7 @@ function get_enclosed($post_id) { // Get enclosures already enclosed for a post
return $pung;
}
-function get_pung($post_id) { // Get URIs already pung for a post
+function get_pung($post_id) { // Get URLs already pung for a post
global $wpdb;
$pung = $wpdb->get_var("SELECT pinged FROM $wpdb->posts WHERE ID = $post_id");
$pung = trim($pung);
@@ -853,7 +853,7 @@ function get_pung($post_id) { // Get URIs already pung for a post
return $pung;
}
-function get_to_ping($post_id) { // Get any URIs in the todo list
+function get_to_ping($post_id) { // Get any URLs in the todo list
global $wpdb;
$to_ping = $wpdb->get_var("SELECT to_ping FROM $wpdb->posts WHERE ID = $post_id");
$to_ping = trim($to_ping);
@@ -1109,7 +1109,7 @@ function generate_page_uri_index() {
foreach ($posts as $id => $post) {
- // URI => page name
+ // URL => page name
$uri = get_page_uri($id);
$attachments = $wpdb->get_results("SELECT ID, post_name, post_parent FROM $wpdb->posts WHERE post_type = 'attachment' AND post_parent = '$id'");
if ( $attachments ) {
diff --git a/wp-includes/query.php b/wp-includes/query.php
index da8749a0f2..55f229ac90 100644
--- a/wp-includes/query.php
+++ b/wp-includes/query.php
@@ -764,7 +764,7 @@ class WP_Query {
$distinct = 'DISTINCT';
}
- // Category stuff for nice URIs
+ // Category stuff for nice URLs
global $cache_categories;
if ('' != $q['category_name']) {
@@ -823,7 +823,7 @@ class WP_Query {
$whichauthor .= ')';
}
- // Author stuff for nice URIs
+ // Author stuff for nice URLs
if ('' != $q['author_name']) {
if (stristr($q['author_name'],'/')) {
diff --git a/wp-includes/rewrite.php b/wp-includes/rewrite.php
index 48fa20b80f..ba5792e9c2 100644
--- a/wp-includes/rewrite.php
+++ b/wp-includes/rewrite.php
@@ -84,7 +84,7 @@ function url_to_postid($url) {
$url_split = explode('#', $url);
$url = $url_split[0];
- // Get rid of URI ?query=string
+ // Get rid of URL ?query=string
$url_split = explode('?', $url);
$url = $url_split[0];
diff --git a/wp-trackback.php b/wp-trackback.php
index 1779c17ae7..463a774e5e 100644
--- a/wp-trackback.php
+++ b/wp-trackback.php
@@ -86,7 +86,7 @@ if ( !empty($tb_url) && !empty($title) && !empty($tb_url) ) {
$dupe = $wpdb->get_results("SELECT * FROM $wpdb->comments WHERE comment_post_ID = '$comment_post_ID' AND comment_author_url = '$comment_author_url'");
if ( $dupe )
- trackback_response(1, 'We already have a ping from that URI for this post.');
+ trackback_response(1, 'We already have a ping from that URL for this post.');
$commentdata = compact('comment_post_ID', 'comment_author', 'comment_author_email', 'comment_author_url', 'comment_content', 'comment_type');
diff --git a/xmlrpc.php b/xmlrpc.php
index 85c432f5d8..e588803c22 100644
--- a/xmlrpc.php
+++ b/xmlrpc.php
@@ -328,7 +328,7 @@ class wp_xmlrpc_server extends IXR_Server {
return new IXR_Error(401, 'Sorry, this user can not edit the template.');
}
/* warning: here we make the assumption that the weblog's URI is on the same server */
$filename = get_settings('home') . '/';
$filename = preg_replace('#https?://.+?/#', $_SERVER['DOCUMENT_ROOT'].'/', $filename);
@@ -363,7 +363,7 @@ class wp_xmlrpc_server extends IXR_Server {
return new IXR_Error(401, 'Sorry, this user can not edit the template.');
}
/* warning: here we make the assumption that the weblog's URI is on the same server */
$filename = get_settings('home') . '/';
$filename = preg_replace('#https?://.+?/#', $_SERVER['DOCUMENT_ROOT'].'/', $filename);
@@ -1153,24 +1153,24 @@ class wp_xmlrpc_server extends IXR_Server {
}
} else {
// TODO: Attempt to extract a post ID from the given URL
- return new IXR_Error(33, 'The specified target URI cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
+ return new IXR_Error(33, 'The specified target URL cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
}
$post_ID = (int) $post_ID;
- logIO("O","(PB) URI='$pagelinkedto' ID='$post_ID' Found='$way'");
+ logIO("O","(PB) URL='$pagelinkedto' ID='$post_ID' Found='$way'");
$post = get_post($post_ID);
if ( !$post ) // Post_ID not found
- return new IXR_Error(33, 'The specified target URI cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
+ return new IXR_Error(33, 'The specified target URL cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
if ( $post_ID == url_to_postid($pagelinkedfrom) )
- return new IXR_Error(0, 'The source URI and the target URI cannot both point to the same resource.');
+ return new IXR_Error(0, 'The source URL and the target URL cannot both point to the same resource.');
// Check if pings are on
if ( 'closed' == $post->ping_status )
- return new IXR_Error(33, 'The specified target URI cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
+ return new IXR_Error(33, 'The specified target URL cannot be used as a target. It either doesn\'t exist, or it is not a pingback-enabled resource.');
// Let's check that the remote site didn't already pingback this entry
$result = $wpdb->get_results("SELECT * FROM $wpdb->comments WHERE comment_post_ID = '$post_ID' AND comment_author_url = '$pagelinkedfrom'");
@@ -1184,7 +1184,7 @@ class wp_xmlrpc_server extends IXR_Server {
// Let's check the remote site
$linea = wp_remote_fopen( $pagelinkedfrom );
if ( !$linea )
- return new IXR_Error(16, 'The source URI does not exist.');
+ return new IXR_Error(16, 'The source URL does not exist.');
// Work around bug in strip_tags():
$linea = str_replace('get_results("SELECT comment_author_url, comment_content, comment_author_IP, comment_type FROM $wpdb->comments WHERE comment_post_ID = $post_ID");
@@ -328,7 +328,7 @@ class wp_xmlrpc_server extends IXR_Server {
return new IXR_Error(401, 'Sorry, this user can not edit the template.');
}
- /* warning: here we make the assumption that the weblog's URI is on the same server */
+ /* warning: here we make the assumption that the weblog's URL is on the same server */
$filename = get_settings('home') . '/';
$filename = preg_replace('#https?://.+?/#', $_SERVER['DOCUMENT_ROOT'].'/', $filename);
@@ -363,7 +363,7 @@ class wp_xmlrpc_server extends IXR_Server {
return new IXR_Error(401, 'Sorry, this user can not edit the template.');
}
- /* warning: here we make the assumption that the weblog's URI is on the same server */
+ /* warning: here we make the assumption that the weblog's URL is on the same server */
$filename = get_settings('home') . '/';
$filename = preg_replace('#https?://.+?/#', $_SERVER['DOCUMENT_ROOT'].'/', $filename);